# Pyburn

[![CI](https://github.com/KwachOjunga/wrap-burn/actions/workflows/CI.yml/badge.svg?branch=master)](https://github.com/KwachOjunga/wrap-burn/actions/workflows/CI.yml)

A modern deep learning framework built to utilize your hardware.
Pyburn leverages the Burn framework to use a diverse range of backends.
In the current version it exposes the ndarray and wgpu backend. `pyburn` offers fusion capabilites
on both backends and allows for both inference and training. 

---
Pyburn is still in its early phase but its foundations are well defined and mature.
There is more to come.